@@ -18,8 +18,9 @@ from runit import RunIt
 
 load_dotenv()
 
-#PROJECTS_DIR = os.path.join(os.getenv('RUNIT_HOMEDIR'), 'projects')
-PROJECTS_DIR = os.path.dirname(os.path.realpath(__file__))
+CURRENT_PATH = os.path.dirname(os.path.realpath(__file__))
+HOMEDIR = os.getenv('RUNIT_HOMEDIR', os.path.realpath(os.path.join(CURRENT_PATH, '..')))
+PROJECTS_DIR = os.path.join(HOMEDIR, 'projects')
 
 def stringifyObjectIds(model: object, properties: list)-> object:
     for property in properties:
